@@ -34,6 +34,9 @@ class Morpholog(pymorphy2.MorphAnalyzer):
     result = []
 
     roots = self.get_roots(word)
+    
+    if roots == None:
+      return word
 
     for root in roots:
       temp = []
@@ -43,9 +46,10 @@ class Morpholog(pymorphy2.MorphAnalyzer):
       for word_i in self.words:
         if (root in word_i):
           roots_word_i = self.get_roots(word_i)
-          for root_word_i in roots_word_i:
-            if root_word_i == root:
-              temp.append(word_i)
+          if roots_word_i != None:
+            for root_word_i in roots_word_i:
+              if root_word_i == root:
+                temp.append(word_i)
       result.append(temp)
       
     return result
@@ -257,7 +261,7 @@ class Morpholog(pymorphy2.MorphAnalyzer):
         if '-' not in morphem and '+' not in morphem:
           roots.append(morphem) 
     if roots == []:
-      return ['']
+      return None
     return roots
   
   def get_prefix(self,word):
